"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const baseProj_1 = require("./baseProj");
const fs_i_1 = require("fs-i");
const globalData_1 = require("../../../model/globalData");
const path = require("path");
const zip_i_1 = require("zip-i");
const util_1 = require("../../../common/util");
const template_1 = require("../../../common/template");
const ProjectType_1 = require("../../../model/ProjectType");
class NodeProj extends baseProj_1.BaseProj {
    getQuestions() {
        let questionList = [
            {
                name: "needDocs",
                type: "list",
                message: "是否需要有开发文档",
                default: "否",
                choices: ["是", "否"]
            },
            {
                name: "unittest",
                type: "list",
                message: "是否需要创建单元测试？",
                default: "否",
                choices: ["是", "否"]
            },
            {
                name: "isCommand",
                type: "list",
                message: "是否创建命令？",
                default: "否",
                choices: ["是", "否"]
            }
        ];
        return questionList;
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            let answer = yield this.getAnswers();
            let templateZipFile = template_1.TemplateData.getProjectTemplate("node.zip");
            yield zip_i_1.unzipPath(templateZipFile, globalData_1.GlobalData.projectRootPath);
            if (answer.needDocs === "是") {
                this.addDocs();
            }
            if (answer.unittest === "是") {
                this.addUnitTest();
            }
            this.createYml(answer);
            this.createProjectConfig(answer);
        });
    }
    addDocs() {
        return __awaiter(this, void 0, void 0, function* () {
            yield util_1.editPackageJson(globalData_1.GlobalData.projectRootPath, json => { });
        });
    }
    addUnitTest() {
        return __awaiter(this, void 0, void 0, function* () {
            yield util_1.editPackageJson(globalData_1.GlobalData.projectRootPath, json => {
                Object.assign(json.devDependencies, {
                    "@types/chai": "^4.1.0",
                    chai: "^4.1.2",
                    "@types/mocha": "^2.2.46",
                    mocha: "^4.1.0"
                });
            });
        });
    }
    createYml(answer) {
        return __awaiter(this, void 0, void 0, function* () {
            let fileContent = `
language: node_js
sudo: enabled
node_js:
  - "8"
before_script:
  - npm i pcreate
  - pcreate test
script:
  - pcreate build
after_script:

cache:
  directories:
    - node_modules

deploy:
  - provider: npm
    skip_cleanup: true
    email: heifade@126.com
    api_key: $NPM_TOKEN
    on:
      branch: master
      repo: heifade/${globalData_1.GlobalData.projectName}
  ${answer.needDocs
                ? `
  - provider: pages
    skip_cleanup: true
    github_token: $GITHUB_TOKEN
    local_dir: docs
    on:
      branch: master`.trim()
                : ""}
`;
            fs_i_1.saveFileUtf8Sync(path.join(globalData_1.GlobalData.projectRootPath, ".travis.yml"), fileContent);
        });
    }
    createProjectConfig(answer) {
        return __awaiter(this, void 0, void 0, function* () {
            let fileContent = `
import { ProjectConfigModel } from "pcreate-config";

let projectConfig: ProjectConfigModel = {
  projectType: "${ProjectType_1.getProjectTypeName(globalData_1.GlobalData.projectType)}",
  compile: {
    outDir: "./es/",
    module: "commonjs",
    target: "es5",
    lib: ["es2015", "es2015.promise", "es2015.symbol"],
    declaration: true
  },
  command: ${answer.isCommand === "是" ? "true" : "false"},
  documents: ${answer.needDocs === "是" ? "true" : "false"},
  unitTest: ${answer.unittest === "是" ? "true" : "false"},
  sourceInclude: ["./src/**/*"]
};

export default projectConfig;
    `;
            fs_i_1.saveFileUtf8Sync(path.join(globalData_1.GlobalData.projectRootPath, "project-config.ts"), fileContent);
        });
    }
}
exports.NodeProj = NodeProj;
//# sourceMappingURL=nodeProj.js.map